@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,13 +24,8 @@
 #include <memory>
 
 #include <QUrl>
-#ifdef QT5
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
-#else
-#include <QHttp>
-#include <QHttpRequestHeader>
-#endif
 #include <QNetworkProxy>
 #include <QMessageBox>
  #include <QCryptographicHash>
@@ -56,20 +51,11 @@ signals:
 	void updateDataReadProgress(int, int);
 	void stateChanged (int);
 
-private slots:
-#ifdef QT5
-    void readResponseHeader(QNetworkReply* reply);
-#else
-    void httpRequestFinished(int requestId, bool error);
-	void readResponseHeader(const QHttpResponseHeader &responseHeader);
-#endif
+  private slots:
+  void readResponseHeader(QNetworkReply* reply);
 
 private:
-#ifdef QT5
-    std::unique_ptr<QNetworkAccessManager> http;
-#else
-	std::unique_ptr<QHttp> http;
-#endif
+  std::unique_ptr<QNetworkAccessManager> http;
 	QString user_agent;
 	QString xmlreply;
     QString page;
