@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2009 by Pavel Zinin (pashazz)                              *
  *   pzinin@gmail.com                                                     *
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -53,36 +53,51 @@ winetricks::winetricks(QString prefixName) : QWidget()
 
 QStringList winetricks::get_installed() {
 
-    QStringList installed_apps;
-
-    if (!check_script())
-        return installed_apps;
-
-    QString infile = QString(winetricks_bin);
-
-    QProcess process;
-
-    QStringList args; // = get_command("list-installed");
-    args.append("-c");
-    args.append(get_command("list-installed").join(" "));
-
-    QString exec = "/bin/sh";
-
-    process.start(exec, args);
-    process.waitForFinished(-1); // will wait forever until finished
-
-    QString stdout = process.readAllStandardOutput();
-    QString stderr = process.readAllStandardError();
-
-    QString pkg_name;
-    foreach(pkg_name, stdout.split("------------------------------------------------------").last().split("\n")){
-        if (!pkg_name.isEmpty()){
-            qDebug() << pkg_name;
-            installed_apps.append(pkg_name);
+    QStringList installed_verbs;
+    qstring_map name_val_settings;
+    QString winver = nullptr;
+    QHash<QString, QString> prefix_info = db_prefix.getByName(this->prefix_name);
+    QString logfile = QString("%1/winetricks.log").arg(CoreLib->getStrictEscapeString(prefix_info.value("path")));
+    QFile file(logfile);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        return installed_verbs;
+    } else {
+        QRegExp winver_regexp("^(nt40|vista|win([0-9][0-9k]?[0-9]?|xp|ver=))$");
+        QTextStream textinputstream(&file);
+        while (!textinputstream.atEnd()) {
+            QString l = textinputstream.readLine();
+            if (textinputstream.status() != QTextStream::Ok) {
+                file.close();
+                return installed_verbs;
+            } else if (installed_verbs.contains(l)) {
+                // Ignore duplicate
+                continue;
+            } else if (l.count('=') == 1 && !l.endsWith('=')) {
+                // For some "name=value" settings,
+                // use map to add the last (valid) one
+                QString key = l.section('=', 0, 0);
+                QString val = l.section('=', 1, 1);
+                // If old "name=value" setting exists, it is overwritten
+                name_val_settings[key] = val;
+            } else {
+                // If the verb is used for setting OS version, add the last one
+                if (winver_regexp.indexIn(l) != -1) {
+                    winver = l;
+                } else {
+                    installed_verbs.append(l);
+                }
+            }
         }
     }
+    file.close();
+    foreach (QString key, name_val_settings.keys()) {
+        installed_verbs.append(QString("%1=%2").arg(key).arg(name_val_settings[key]));
+    }
+    if (winver != nullptr) {
+        installed_verbs.append(winver);
+    }
 
-    return installed_apps;
+    return installed_verbs;
 }
 
 void winetricks::install_winetricks() {
@@ -138,10 +153,11 @@ void winetricks::run_winetricks(QString item){
 
 QStringList winetricks::get_command(QString item){
     QStringList sh_args;
-    QString proxy_host = CoreLib->getSetting("network", "host", false).toString();
+    int proxy_type = CoreLib->getSetting("network", "type", false, 0).toInt();
     sh_args.append("env");
 
-    if (!proxy_host.isEmpty()){
+    if (proxy_type > 0){
+        QString proxy_host = CoreLib->getSetting("network", "host", false).toString();
         QString proxy_auth = CoreLib->getSetting("network", "user", false).toString();
         if (!proxy_auth.isEmpty()){
             QString proxy_pass = CoreLib->getSetting("network", "pass", false).toString();
