@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -225,21 +225,22 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
         cbUseSingleClick->setChecked(true);
     }
 
-#if QT_VERSION >= 0x040500
     if (settings.value("useNativeFileDialog", 1).toInt()==1){
         cbUseNativeDialog->setChecked(true);
     } else {
         cbUseNativeDialog->setChecked(false);
     }
-#else
-    cbUseNativeDialog->setEnabled(false);
-#endif
 
     QString res = settings.value("defaultDesktopSize").toString();
     if (res.isEmpty()){
         cboxDesktopSize->setCurrentIndex(0);
     } else {
-        cboxDesktopSize->setCurrentIndex(cboxDesktopSize->findText(res));
+        int i = cboxDesktopSize->findText(res);
+        if (i >= 0) {
+            cboxDesktopSize->setCurrentIndex(i);
+        } else {
+            cboxDesktopSize->setCurrentText(res);
+        }
     }
 
     settings.endGroup();
@@ -380,44 +381,38 @@ bool AppSettings::eventFilter(QObject *obj, QEvent *event){
       */
 
     if (event->type() == QEvent::MouseButtonRelease) {
+        QString file;
+        QString obj_name;
+        QString search_path;
 
-        QString file="";
+        obj_name.append("txt");
+        obj_name.append(obj->objectName().right(obj->objectName().length()-6));
+
+        std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(obj_name));
+        search_path = lineEdit.get()->text();
 
-#if QT_VERSION >= 0x040500
         QFileDialog::Options options;
 
         if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
                 options = QFileDialog::DontUseNativeDialog | QFileDialog::DontResolveSymlinks;
 
         if (obj->objectName().right(3)=="Bin"){
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(),   "All files (*)", 0, options);
+            file = QFileDialog::getOpenFileName(this, tr("Open File"), search_path, "All files (*)", 0, options);
         } else {
-            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath(),  options);
+            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), search_path,  options);
         }
-#else
-        if (obj->objectName().right(3)=="Bin"){
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(),   "All files (*)");
-        } else {
-            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath());
-        }
-#endif
 
         if (!file.isEmpty()){
-            QString a="";
-
-            a.append("txt");
-            a.append(obj->objectName().right(obj->objectName().length()-6));
-
-            std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(a));
-
             if (lineEdit.get()){
                 lineEdit->setText(file);
             } else {
                 qDebug("Error getting lineEdit object");
             }
 
-            lineEdit.release();
+
         }
+
+        lineEdit.release();
     }
 
     return false;
@@ -664,17 +659,22 @@ void AppSettings::cmdOk_Click(){
         settings.setValue("useSingleClick", 0);
     }
 
-#if QT_VERSION >= 0x040500
     if (cbUseNativeDialog->isChecked()){
         settings.setValue("useNativeFileDialog", 1);
     } else {
         settings.setValue("useNativeFileDialog", 0);
     }
-#endif
 
     QString desktopSize=cboxDesktopSize->currentText();
-    if (desktopSize==tr("No virtual desktop"))
+    if (desktopSize==tr("No virtual desktop")){
         desktopSize="";
+    } else {
+        QRegExp res_match("^\\d{3,}x\\d{3,}$");
+        if (!res_match.exactMatch(desktopSize)){
+            QMessageBox::warning(this, tr("Error"), tr("Invalid virtual desktop size."));
+            return;
+        }
+    }
 
     settings.setValue("defaultDesktopSize", desktopSize);
 
