@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -86,11 +86,7 @@ FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::W
     QSettings settings(APP_SHORT_NAME, "default");
     settings.beginGroup("LastItems");
     txtPostRunBin->addItems(settings.value("prefix").toStringList());
-#if QT_VERSION >= 0x050000
     txtPostRunBin->setCurrentText("");
-#else
-    txtPostRunBin->setEditText("");
-#endif
     settings.endGroup();
 
 }
@@ -1422,44 +1418,44 @@ bool FakeDriveSettings::eventFilter(QObject *obj, QEvent *event){
 
     if (event->type() == QEvent::MouseButtonRelease) {
         QString file;
+        QString obj_name;
+        QString search_path;
+
+        obj_name.append("txt");
+        obj_name.append(obj->objectName().right(obj->objectName().length()-6));
+        if (QString("%1").arg(findChild<QWidget *>(obj_name)->metaObject()->className()) == "QComboBox") {
+            std::unique_ptr<QComboBox> cbEdit (findChild<QComboBox *>(obj_name));
+            search_path = cbEdit.get()->currentText();
+            cbEdit.release();
+        } else {
+            std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(obj_name));
+            search_path = lineEdit.get()->text();
+            lineEdit.release();
+        }
 
-#if QT_VERSION >= 0x040500
         QFileDialog::Options options;
 
         if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
                 options = QFileDialog::DontUseNativeDialog | QFileDialog::DontResolveSymlinks;
 
         if (obj->objectName().right(3)=="Bin"){
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(), "All files (*)", 0, options);
+            file = QFileDialog::getOpenFileName(this, tr("Open File"), search_path, "All files (*)", 0, options);
         } else {
-            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath(),  options);
+            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), search_path,  options);
         }
-#else
-        if (obj->objectName().right(3)=="Bin"){
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(),   "All files (*)");
-        } else {
-            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath());
-        }
-#endif
-        if (!file.isEmpty()){
-            QString a;
-            a.append("txt");
-            a.append(obj->objectName().right(obj->objectName().length()-6));
 
-            if (QString("%1").arg(findChild<QWidget *>(a)->metaObject()->className()) == "QComboBox") {
-                std::unique_ptr<QComboBox> cbEdit (findChild<QComboBox *>(a));
+        if (!file.isEmpty()){
+
+            if (QString("%1").arg(findChild<QWidget *>(obj_name)->metaObject()->className()) == "QComboBox") {
+                std::unique_ptr<QComboBox> cbEdit (findChild<QComboBox *>(obj_name));
                 if (cbEdit.get()){
-#if QT_VERSION >= 0x050000
                     cbEdit->setCurrentText(file);
-#else
-                    cbEdit->setEditText(file);
-#endif
                 } else {
                     qDebug("Error");
                 }
                 cbEdit.release();
             } else {
-                std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(a));
+                std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(obj_name));
                 if (lineEdit.get()){
                     lineEdit->setText(file);
                 } else {
