@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -83,7 +83,16 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
             if (res.isEmpty()){
                 cboxDesktopSize->setCurrentIndex(0);
             } else {
-                cboxDesktopSize->setCurrentIndex(cboxDesktopSize->findText(res));
+                if (res.isEmpty()){
+                    cboxDesktopSize->setCurrentIndex(0);
+                } else {
+                    int i = cboxDesktopSize->findText(res);
+                    if (i >= 0) {
+                        cboxDesktopSize->setCurrentIndex(i);
+                    } else {
+                        cboxDesktopSize->setCurrentText(res);
+                    }
+                }
             }
     } else {
             setWindowTitle(tr("Icon settings"));
@@ -169,7 +178,17 @@ void IconSettings::getIconReccord(){
     if (iconRec.value("desktop").isEmpty()){
         cboxDesktopSize->setCurrentIndex(0);
     } else {
-        cboxDesktopSize->setCurrentIndex(cboxDesktopSize->findText(iconRec.value("desktop")));
+        QString res = iconRec.value("desktop");
+        if (res.isEmpty()){
+            cboxDesktopSize->setCurrentIndex(0);
+        } else {
+            int i = cboxDesktopSize->findText(res);
+            if (i >= 0) {
+                cboxDesktopSize->setCurrentIndex(i);
+            } else {
+                cboxDesktopSize->setCurrentText(res);
+            }
+        }
     }
 
     spinNice->setValue(iconRec.value("nice").toInt());
@@ -264,19 +283,17 @@ void IconSettings::cbUseConsole_stateChanged(int){
 
 void IconSettings::cmdGetWorkDir_Click(){
 
-    QString fileName, searchPath=this->prefix_path;
+    QString fileName, searchPath;
 
-    if ((!txtProgramPath->text().isEmpty()) and (QDir().exists(txtProgramPath->text()))){
-        searchPath=txtProgramPath->text().left(txtProgramPath->text().length() - txtProgramPath->text().split("/").last().length());;
-    }
-
-    if (!QDir(searchPath).exists()){
-        if (QDir(this->prefix_path).exists()){
-           searchPath=this->prefix_path;
+    if (txtWorkDir->text().isEmpty()){
+        searchPath = this->prefix_path;
+    } else {
+        if (QDir(txtWorkDir->text()).exists()) {
+            searchPath = txtWorkDir->text();
         } else {
-           searchPath=QDir::homePath();
+            searchPath = this->prefix_path;
         }
-     }
+    }
 
     QFileDialog dialog(this);
       dialog.setFilter(QDir::Dirs | QDir::Hidden);
@@ -285,11 +302,9 @@ void IconSettings::cmdGetWorkDir_Click(){
       dialog.setWindowTitle(tr("Open Directory"));
       dialog.setDirectory(searchPath);
 
-#if QT_VERSION >= 0x040500
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
-#endif
 
     if (dialog.exec())
         fileName = dialog.selectedFiles().first();
@@ -321,24 +336,18 @@ void IconSettings::cmdAdd_Click(){
 }
 
 void IconSettings::cmdGetProgram_Click(){
-    QString fileName, searchPath = this->prefix_path;
+    QString fileName, searchPath;
 
-    if (!txtProgramPath->text().isEmpty()){
-        if (!txtWorkDir->text().isEmpty()){
-        searchPath=txtWorkDir->text();
+    if (txtProgramPath->text().isEmpty()){
+        searchPath = this->prefix_path;
+    } else {
+        if (QFile(txtProgramPath->text()).exists()){
+            searchPath = QFileInfo(txtProgramPath->text()).absolutePath();
         } else {
-        searchPath=txtProgramPath->text().left(txtProgramPath->text().length() - txtProgramPath->text().split("/").last().length());;
+            searchPath = this->prefix_path;
         }
     }
 
-    if ((!QDir(searchPath).exists()) or (searchPath.isEmpty())){
-        if (QDir(dir_name).exists()){
-           searchPath=this->prefix_path;
-        } else {
-           searchPath=QDir::homePath();
-        }
-     }
-
     QFileDialog dialog(this);
       dialog.setFilter(QDir::Dirs | QDir::Files | QDir::Hidden );
       dialog.setWindowTitle(tr("Open Exe file"));
@@ -346,12 +355,9 @@ void IconSettings::cmdGetProgram_Click(){
       dialog.setFileMode(QFileDialog::ExistingFile);
       dialog.setNameFilter(tr("Exe, MSI, BAT files (*.exe *.EXE *.msi *.MSI *.bat *.BAT);;Exe files (*.exe *.EXE);;MSI files (*.msi *.MSI);;BAT files (*.bat *.BAT);;All files (*)"));
 
-
-#if QT_VERSION >= 0x040500
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
-#endif
 
      if (dialog.exec())
         fileName = dialog.selectedFiles().first();
@@ -406,11 +412,9 @@ void IconSettings::cmdGetIcon_Click(){
       dialog.setFileMode(QFileDialog::ExistingFile);
       dialog.setWindowTitle(tr("Open image file"));
 
-#if QT_VERSION >= 0x040500
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
-#endif
 
       if ((!iconPath.isEmpty()) and (QFile(iconPath).exists())){
           QStringList list = iconPath.split("/");
@@ -599,8 +603,15 @@ void IconSettings::cmdOk_Click(){
 
     QString desktopSize=cboxDesktopSize->currentText();
 
-    if (desktopSize==tr("No virtual desktop"))
+    if (desktopSize==tr("No virtual desktop")) {
         desktopSize="";
+    } else {
+        QRegExp res_match("^\\d{3,}x\\d{3,}$");
+        if (!res_match.exactMatch(desktopSize)){
+            QMessageBox::warning(this, tr("Error"), tr("Invalid virtual desktop size."));
+            return;
+        }
+    }
 
     if (this->icon_name.isEmpty()){
             db_icon.addIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text(), txtPreRun->text(), txtPostRun->text());
@@ -648,8 +659,13 @@ void IconSettings::cmdHelp_Click(){
 
 void IconSettings::cmdGetPreRun_Click(){
     QString fileName;
-    QString searchPath = QDir::homePath();
-    searchPath.append("/.config/q4wine/scripts");
+    QString searchPath = "";
+    if (txtPreRun->text().isEmpty()) {
+        searchPath = QDir::homePath();
+        searchPath.append("/.config/q4wine/scripts");
+    } else {
+        searchPath = QFileInfo(txtPreRun->text()).absolutePath();
+    }
     QFileDialog dialog(this);
     dialog.setFilter(QDir::Dirs | QDir::Files | QDir::Hidden );
     dialog.setWindowTitle(tr("Open Exe file"));
@@ -657,23 +673,26 @@ void IconSettings::cmdGetPreRun_Click(){
     dialog.setFileMode(QFileDialog::ExistingFile);
     dialog.setNameFilter(tr("Shell script (*.sh)"));
 
-#if QT_VERSION >= 0x040500
     if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
         dialog.setOptions(QFileDialog::DontUseNativeDialog);
     }
-#endif
 
-    if (dialog.exec())
+    if (dialog.exec()){
        fileName = dialog.selectedFiles().first();
-
-    txtPreRun->setText(fileName);
+       txtPreRun->setText(fileName);
+    }
     return;
 }
 
 void IconSettings::cmdGetPostRun_Click(){
     QString fileName;
-    QString searchPath = QDir::homePath();
-    searchPath.append("/.config/q4wine/scripts");
+    QString searchPath = "";
+    if (txtPostRun->text().isEmpty()) {
+        searchPath = QDir::homePath();
+        searchPath.append("/.config/q4wine/scripts");
+    } else {
+        searchPath = QFileInfo(txtPostRun->text()).absolutePath();
+    }
     QFileDialog dialog(this);
     dialog.setFilter(QDir::Dirs | QDir::Files | QDir::Hidden );
     dialog.setWindowTitle(tr("Open Exe file"));
@@ -681,11 +700,9 @@ void IconSettings::cmdGetPostRun_Click(){
     dialog.setFileMode(QFileDialog::ExistingFile);
     dialog.setNameFilter(tr("Shell script (*.sh)"));
 
-#if QT_VERSION >= 0x040500
     if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
         dialog.setOptions(QFileDialog::DontUseNativeDialog);
     }
-#endif
 
     if (dialog.exec())
        fileName = dialog.selectedFiles().first();
