@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -295,30 +295,32 @@ bool PrefixSettings::eventFilter(QObject *obj, QEvent *event){
 
     if (event->type() == QEvent::MouseButtonRelease) {
 
-        QString file="";
+        QString file;
+        QString obj_name;
+        QString search_path;
+
+        obj_name.append("txt");
+        obj_name.append(obj->objectName().right(obj->objectName().length()-6));
+
+        std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(obj_name));
+        search_path = lineEdit.get()->text();
 
         if (obj->objectName().right(3)=="Bin"){
-#if QT_VERSION >= 0x040500
             QFileDialog::Options options;
 
             if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
                 options = QFileDialog::DontUseNativeDialog;
 
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(), "All files (*)", 0, options);
-#else
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(), "All files (*)");
-#endif
+            file = QFileDialog::getOpenFileName(this, tr("Open File"), search_path, "All files (*)", 0, options);
+
         } else {
-#if QT_VERSION >= 0x040500
+
             QFileDialog::Options options;
 
             if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
                 options = QFileDialog::DontUseNativeDialog;
 
-            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath(), options);
-#else
-            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath(), QFileDialog::DontResolveSymlinks);
-#endif
+            file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), search_path, options);
         }
 
         if (!file.isEmpty()){
@@ -326,13 +328,6 @@ bool PrefixSettings::eventFilter(QObject *obj, QEvent *event){
                 file=file.left(file.length()-1);
             }
 
-            QString a="";
-
-            a.append("txt");
-            a.append(obj->objectName().right(obj->objectName().length()-6));
-
-            std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(a));
-
             if (lineEdit.get()){
                 lineEdit->setText(file);
             } else {
@@ -350,6 +345,7 @@ bool PrefixSettings::eventFilter(QObject *obj, QEvent *event){
             }
 
         }
+        lineEdit.release();
     }
 
     return false;
