@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -53,7 +53,12 @@ Run::Run(QWidget * parent, Qt::WindowFlags f) : QDialog(parent, f)
     if (res.isEmpty()){
         cboxDesktopSize->setCurrentIndex(0);
     } else {
-        cboxDesktopSize->setCurrentIndex(cboxDesktopSize->findText(res));
+        int i = cboxDesktopSize->findText(res);
+        if (i >= 0) {
+            cboxDesktopSize->setCurrentIndex(i);
+        } else {
+            cboxDesktopSize->setCurrentText(res);
+        }
     }
 
     twDlls->horizontalHeader()->setStretchLastSection(true);
@@ -91,8 +96,14 @@ void Run::prepare(QString prefix_name, QString wrkdir, QString override, QString
     if (useconsole=="1")
         cbUseConsole->setChecked(true);
 
-    if (!desktop.isEmpty())
-        cboxDesktopSize->setCurrentIndex(cboxDesktopSize->findText(desktop));
+    if (!desktop.isEmpty()) {
+        int i = cboxDesktopSize->findText(desktop);
+        if (i >= 0) {
+            cboxDesktopSize->setCurrentIndex(i);
+        } else {
+            cboxDesktopSize->setCurrentText(desktop);
+        }
+    }
 
     if (!override.isEmpty()){
         QStringList overrideS = override.split(";");
@@ -206,6 +217,11 @@ void Run::cmdOk_Click(){
     if (cboxDesktopSize->currentText()==tr("No virtual desktop")){
         execObj.desktop="";
     } else {
+        QRegExp res_match("^\\d{3,}x\\d{3,}$");
+        if (!res_match.exactMatch(cboxDesktopSize->currentText())){
+            QMessageBox::warning(this, tr("Error"), tr("Invalid virtual desktop size."));
+            return;
+        }
         execObj.desktop=cboxDesktopSize->currentText();
     }
 
@@ -317,22 +333,15 @@ void Run::cbUseConsole_stateChanged(int){
 
 void Run::cmdGetProgram_Click(){
 
-    QString fileName="";
-    QString searchPath=prefix_dir;
+    QString fileName, searchPath;
 
-    if (!txtProgramBin->text().isEmpty()){
-        if (!txtWorkDir->text().isEmpty()){
-            searchPath=txtWorkDir->text();
+    if (txtProgramBin->text().isEmpty()){
+        searchPath = prefix_dir;
+    } else {
+        if (QFile(txtProgramBin->text()).exists()){
+            searchPath = QFileInfo(txtProgramBin->text()).absolutePath();
         } else {
-            searchPath=txtProgramBin->text().left(txtProgramBin->text().length() - txtProgramBin->text().split("/").last().length());;
-        }
-    }
-
-    if ((!QDir(searchPath).exists()) or (searchPath.isEmpty())){
-        if (QDir(prefix_dir).exists()){
-            searchPath=prefix_dir;
-        } else {
-            searchPath=QDir::homePath();
+            searchPath = prefix_dir;
         }
     }
 
@@ -344,11 +353,9 @@ void Run::cmdGetProgram_Click(){
     dialog.setNameFilter(tr("Exe, MSI, BAT files (*.exe *.EXE *.msi *.MSI *.bat *.BAT);;Exe files (*.exe *.EXE);;MSI files (*.msi *.MSI);;BAT files (*.bat *.BAT);;All files (*)"));
     //dialog.setSidebarUrls(prefix_urls);
 
-#if QT_VERSION >= 0x040500
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
-#endif
 
     if (dialog.exec())
         fileName = dialog.selectedFiles().first();
@@ -366,18 +373,16 @@ void Run::cmdGetProgram_Click(){
 }
 
 void Run::cmdGetWorkDir_Click(){
-    QString searchPath=prefix_dir;
-    QString fileName="";
 
-    if ((!txtProgramBin->text().isEmpty()) and (QDir().exists(txtProgramBin->text()))){
-        searchPath=txtProgramBin->text().left(txtProgramBin->text().length() - txtProgramBin->text().split("/").last().length());;
-    }
+    QString fileName, searchPath;
 
-    if (!QDir(searchPath).exists()){
-        if (QDir(prefix_dir).exists()){
-            searchPath=prefix_dir;
+    if (txtWorkDir->text().isEmpty()){
+        searchPath = prefix_dir;
+    } else {
+        if (QDir(txtWorkDir->text()).exists()) {
+            searchPath = txtWorkDir->text();
         } else {
-            searchPath=QDir::homePath();
+            searchPath = prefix_dir;
         }
     }
 
@@ -398,14 +403,10 @@ void Run::cmdGetWorkDir_Click(){
     dialog.setFileMode(QFileDialog::Directory);
     dialog.setWindowTitle(tr("Open Directory"));
     dialog.setDirectory(searchPath);
-    // This option wirksonly it qt 4.5. In fact this not works correctly with QDir::Hidden,  so I comment it out for a some  time
-    //dialog.setOption(QFileDialog::ShowDirsOnly, true);
 
-#if QT_VERSION >= 0x040500
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
-#endif
 
     dialog.setSidebarUrls(prefix_urls);
     if (dialog.exec())
