@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -55,8 +55,6 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
     QDir dir("/proc");
     if (!dir.exists()){
         if (this->showError(message, false) == QMessageBox::Ignore){
-        //    procline << "-1";
-        //    proclist << procline;
             proclist.clear();
             return proclist;
         }
@@ -109,6 +107,7 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
                 path = "/proc/";
                 path.append(fileInfo.fileName());
                 path.append("/stat");
+
                 QFile file_s(path);
                 if (file_s.open(QIODevice::ReadOnly | QIODevice::Text)){
                     // Try to read com file
@@ -133,16 +132,19 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
                             // Try to read environ file
                             QTextStream e_in(&file_e);
                             QString e_line = e_in.readLine();
-                            int index = e_line.indexOf("WINEPREFIX=");
-                            prefix="";
-                            if (index!=-1)
-                                for (int i=index+11; i<=e_line.length(); i++){
-                                    if (e_line.mid(i, 1).data()->isPrint()){
-                                        prefix.append(e_line.mid(i, 1));
-                                    } else {
-                                        break;
+                            while(!e_line.isNull()) {
+                                int index = e_line.indexOf("WINEPREFIX=");
+                                prefix="";
+                                if (index!=-1)
+                                    for (int i=index+11; i<=e_line.length(); i++){
+                                        if (e_line.mid(i, 1).data()->isPrint()){
+                                            prefix.append(e_line.mid(i, 1));
+                                        } else {
+                                            break;
+                                        }
                                     }
-                                }
+                                e_line = e_in.readLine();
+                            }
                             file_e.close();
                         }
 
@@ -334,7 +336,25 @@ void corelib::checkSettings(){
     this->getSetting("system", "mount");
     this->getSetting("system", "umount");
     this->getSetting("system", "sudo");
-    this->getSetting("system", "gui_sudo");
+    if (this->getWhichOut(this->getSetting("system", "gui_sudo", false).toString(), false).isEmpty()){
+        QStringList guisudo;
+#ifdef _OS_DARWIN_
+        guisudo << "osascript";
+#else
+        guisudo << "pkexec" << "kdesudo" << "kdesu" << "gksudo" << "gksu" << "sudo";
+#endif
+        foreach (QString bin, guisudo){
+            QString path = this->getWhichOut(bin, false);
+            if (!path.isEmpty()){
+                QSettings settings(APP_SHORT_NAME, "default");
+                settings.beginGroup("system");
+                settings.setValue("gui_sudo", path);
+                settings.endGroup();
+                break;
+            }
+        }
+        this->getSetting("system", "gui_sudo");
+    }
     this->getSetting("system", "nice");
     this->getSetting("system", "renice");
     this->getSetting("system", "sh");
@@ -529,11 +549,6 @@ void corelib::getBuildFlags(){
     QTextStream Qcout(stdout);
     Qcout<<QObject::tr("Buildtime flags are:")<<endl<<endl;
     Qcout<<qSetFieldWidth(25)<<left<<" CMAKE_INSTALL_PREFIX"<<QString::fromUtf8(APP_PREF)<<qSetFieldWidth(0)<<endl<<endl;
-#ifdef QT5
-    Qcout<<qSetFieldWidth(25)<<left<<" QT5"<<"ON"<<qSetFieldWidth(0)<<endl;
-#else
-    Qcout<<qSetFieldWidth(25)<<left<<" QT5"<<"OFF"<<qSetFieldWidth(0)<<endl;
-#endif
 #ifdef RELEASE
     Qcout<<qSetFieldWidth(25)<<left<<" RELEASE"<<"ON"<<qSetFieldWidth(0)<<endl;
 #else
@@ -1445,6 +1460,7 @@ QStringList corelib::getCdromDevices(void) const{
 
             if (!myProcess.waitForFinished())
                 return false;
+
             int exitcode = myProcess.exitCode();
             QProcess::ExitStatus exitStatus = myProcess.exitStatus();
             if (showLog && (exitcode != 0 || exitStatus == QProcess::CrashExit)){
@@ -1488,16 +1504,98 @@ QStringList corelib::getCdromDevices(void) const{
             return;
         }
 
-        bool corelib::killWineServer(const QString prefix_path){
+        bool corelib::killWineServer(const QString prefix_path, const QString pid){
 
-            ExecObject execObj;
-            execObj.cmdargs = "-kill";
-            execObj.execcmd = "wineserver";
+            if (!pid.isEmpty()){
 
-            if (!this->runWineBinary(execObj, db_prefix.getName(prefix_path), false)){
-                return false;
+#ifdef _OS_LINUX_
+
+                QString message;
+
+                // Check for /proc directory exists
+                QDir dir("/proc");
+                if (!dir.exists()){
+                    message = "<p>Process is unable to access /proc file system.</p><p>Access is necessary for displaying Wine process information.</p><p>You need to set CONFIG_PROC_FS=y option on linux kernel config file and mount proc file system by running: mount -t proc none /proc</p>";
+                    if (this->showError(message, false) == QMessageBox::Ignore){
+                        return false;
+                    }
+                }
+
+                QFileInfo info(QString("/proc/%1/exe").arg(pid));
+                if (info.isSymLink()) {
+                    QString fileName = info.symLinkTarget();
+#ifdef DEBUG
+                    qDebug()<< "Traget for: " << info.filePath() << " is: " << fileName;
+#endif
+                    if ((!fileName.contains("wine") && !fileName.contains(".exe")) || fileName.contains(APP_SHORT_NAME)){
+                        message = "Not an wine process.";
+                        if (this->showError(message, false) == QMessageBox::Ignore){
+                            return false;
+                        }
+                    }
+                } else {
+                    message = "Not an wine process.";
+                    if (this->showError(message, false) == QMessageBox::Ignore){
+                        return false;
+                    }
+                }
+
+                QStringList args;
+                QStringList keywords;
+                keywords << "WINEPREFIX" << "WINEARCH" << "WINELOADERNOEXEC";
+                keywords << "WINESERVERSOCKET" << "WINEDLLPATH" << "WINEESYNC" << "PATH";
+                keywords << "WINESERVER" << "WINELOADER";
+
+                QFile file_e(QString("/proc/%1/environ").arg(pid));
+                // Getting WINE* variables.
+                if (file_e.open(QIODevice::ReadOnly | QIODevice::Text)){
+                    // Try to read environ file
+                    QTextStream e_in(&file_e);
+                    QString e_line = e_in.readLine();
+
+                    while(!e_line.isNull()) {
+                        qDebug() << e_line;
+                        foreach (const QString &env, e_line.split("\0")) {
+                            QRegExp rx_env("^(.*)=(.*)?");
+                            if (rx_env.indexIn(env) != -1){
+                                if (keywords.contains(rx_env.cap(1))){
+                                    args << env;
+                                }
+                            }
+                        }
+                        e_line = e_in.readLine();
+                    }
+                    file_e.close();
+                }
+
+                args << "wineserver";
+                args << "-k";
+
+#ifdef DEBUG
+                qDebug() << args;
+#endif
+
+                return this->runProcess(this->getWhichOut("env"), args);
+#else
+                //FIXME: FreeBSD and MacOS hooks required
+                ExecObject execObj;
+                execObj.cmdargs = "-kill";
+                execObj.execcmd = "wineserver";
+
+                if (!this->runWineBinary(execObj, db_prefix.getName(prefix_path), false)){
+                    return false;
+                }
+#endif
+
+            } else {
+                ExecObject execObj;
+                execObj.cmdargs = "-kill";
+                execObj.execcmd = "wineserver";
+
+                if (!this->runWineBinary(execObj, db_prefix.getName(prefix_path), false)){
+                    return false;
+                }
             }
-
             return true;
         }
 
@@ -1770,7 +1868,7 @@ QStringList corelib::getCdromDevices(void) const{
 
             QString sudobin = this->getSetting("system", "gui_sudo").toString();
 
-            if (!sudobin.contains(QRegExp("/sudo$"))){
+            if (!sudobin.contains(QRegExp("/(sudo|pkexec)$"))){
                 QString arg =args.join(" ");
                 args.clear();
                 args.append(arg);
