@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -222,7 +222,7 @@ public:
      * \param  prefix_path	Prefix name.
      * \return Return an list of cdrom devices.
      */
-    bool killWineServer(const QString prefix_path);
+    bool killWineServer(const QString prefix_path, const QString pid);
 
     /*! \brief Prepare icon data for run wine.
      *
